<?php
/**
 * A Stackable interface
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2011 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface Stackable extends FrameworkInterface {
	/**
	 * Pushs a value on a named stacker
	 *
	 * @param	$stackerName	Name of the stacker
	 * @param	$value			Value to push on it
	 * @return	void
	 * @throws	StackerFullException	If the stacker is full
	 */
	function pushNamed ($stackerName, $value);

	/**
	 * 'Pops' a value from a named stacker and returns it's value
	 *
	 * @param	$stackerName	Name of the stacker
	 * @return	$value			Value of the current stack entry
	 * @throws	NoStackerException	If the named stacker was not found
	 * @throws	EmptyStackerException	If the named stacker is empty
	 */
	function popNamed ($stackerName);

	/**
	 * Get value from named stacker but don't "pop" it
	 *
	 * @param	$stackerName	Name of the stacker
	 * @return	$value			Value of last added value
	 * @throws	NoStackerException	If the named stacker was not found
	 * @throws	EmptyStackerException	If the named stacker is empty
	 */
	function getNamed ($stackerName);

	/**
	 * Checks wether the given stack is initialized (set in array $stackers)
	 *
	 * @param	$stackerName	Name of the stack
	 * @return	$isInitialized	Wether the stack is initialized
	 */
	function isStackInitialized ($stackerName);

	/**
	 * Checks wether the given stack is empty
	 *
	 * @param	$stackerName	Name of the stack
	 * @return	$isEmpty			Wether the stack is empty
	 * @throws	NoStackerException	If given stack is missing
	 */
	function isStackEmpty ($stackerName);
}

// [EOF]
?>
